note 100359 deleted from function.touch by danbrown
| From: | danbrown@php.net | Date: | Mon, 11 Oct 2010 16:42:37 +0000 |
| Subject: | note 100359 deleted from function.touch by danbrown | ||
| References: | 1 | Groups: | php.notes |
| Request: | Send a blank email to php-notes+get-173140@lists.php.net to get a copy of this message | ||
Note Submitter: delphists at apollo dot lv
----
bosslog at gmail dot com, I tested touch() vs file_put_contents() - touch() was about 10% faster:
* 100 iterations:
0.00586 secs - touch
0.00699 secs - file_put_contents
* 1000 iterations:
0.07829 secs - touch
0.08730 secs - file_put_contents
* 10000 iterations:
0.87133 secs - touch
0.96105 secs - file_put_contents
* 100000 iterations:
9.51271 secs - touch
10.31091 secs - file_put_contents